@@ -15,15 +15,20 @@ val to_alcotest :
   ?colors:bool -> ?verbose:bool -> ?long:bool ->
   ?debug_shrink:(out_channel option) ->
   ?debug_shrink_list:(string list) ->
-  ?rand:Random.State.t ->
+  ?speed_level:Alcotest.speed_level -> ?rand:Random.State.t ->
   QCheck2.Test.t -> unit Alcotest.test_case
 (** Convert a qcheck test into an alcotest test.
 
-    In addition to the environment variables mentioned above, you can control
-    the behavior of QCheck tests using optional parameters that behave in the
-    same way as the parameters of {!QCheck_base_runner.run_tests}.
+    The optional [speed_level] is [`Slow] by default, meaning Alcotest can skip
+    such a test when the [-q] flag is passed. Passing [`Quick] instead means the
+    test is always run.
+
+    In addition to [speed_level] and the environment variables mentioned above,
+    you can control the behavior of QCheck tests using optional parameters that
+    behave in the same way as the parameters of {!QCheck_base_runner.run_tests}.
 
     @since 0.9
     @since 0.9 parameters [verbose], [long], [rand]
     @since 0.19 parameters [colors], [debug_shrink], [debug_shrink_list]
+    @since 0.24 parameter [speed_level]
 *)
