@@ -63,6 +63,9 @@ val set_long_tests : bool -> unit
     will only print a console message every 7.5 seconds. This feature can be
     useful in a CI context, where updates are printed on consecutive lines and
     one may want to avoid overflowing the CI log files with too many lines.
+
+    Note: The start and finishing message for each test is printed eagerly
+    in verbose mode regardless of the specified message interval.
 *)
 
 val get_time_between_msg : unit -> float
@@ -179,11 +182,11 @@ Called from file "src/QCheck.ml", line 839, characters 13-33
 
 Collect results for test collect_results:
 
-4: 207 cases
-3: 190 cases
-2: 219 cases
-1: 196 cases
-0: 188 cases
+ 4:     207 cases (20.7%)
+ 3:     190 cases (19.0%)
+ 2:     219 cases (21.9%)
+ 1:     196 cases (19.6%)
+ 0:     188 cases (18.8%)
 
 ================================================================================
 failure (1 tests failed, 1 tests errored, ran 4 tests)
